@@ -2,9 +2,10 @@
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import relation, relationship
 from sqlalchemy import Column, ForeignKey
-from sqlalchemy.types import Numeric, Integer, Text, String, Date, DateTime, Time, Boolean, Enum, Float
+from sqlalchemy.types import Numeric, Integer, Text, String, Date, DateTime, Time, Boolean, Enum, Float, Table
 from sqlalchemy.sql.sqltypes import Boolean
 from sqlalchemy.sql import func
+from sqlalchemy import orm
 import enum
 
 from scrapeanything.utils.types import Types
