@@ -1,6 +1,7 @@
 from datetime import datetime, date, time
 from sqlalchemy import create_engine, event
 from sqlalchemy.orm import scoped_session, sessionmaker, aliased, mapper
+from sqlalchemy import Table
 from sqlalchemy.dialects import mysql
 from sqlalchemy import exists, desc, text, and_
 from sqlalchemy.inspection import inspect
@@ -17,7 +18,7 @@ class Repository:
     def __init__(self, config: Config) -> None:
         self.config = config
 
-        is_debug = True if self.config.get(section='COMMANDS', key='debug') == 'True' else False
+        is_debug = self.config.get(section='COMMANDS', key='debug')
 
         username = self.config.get(section='DATABASE', key='username')
         password = self.config.get(section='DATABASE', key='password')
